@@ -1,6 +1,6 @@
 package Benchmark::Harness;
 use strict;
-use vars qw($VERSION); $VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+use vars qw($VERSION); $VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 =pod
 
@@ -607,12 +607,14 @@ Benchmark::Harness sub-classing
 Revision 1.2  2004/09/03 19:55:29  woodg
 some POD
 
-=head1 COPYRIGHT
-
-(c) 2004 Yahoo, Inc.
-
 =head1 AUTHOR
 
-Glenn Wood <Glenn.Wood@Oveture.com>
+Glenn Wood, <glennwood@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2004 Glenn Wood. All rights reserved.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
 
 =cut
