@@ -55,4 +55,16 @@ sub onSubExit {
 
 ### ###########################################################################
 
+=head1 AUTHOR
+
+Glenn Wood, <glennwood@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2004 Glenn Wood. All rights reserved.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
+
 1;
\ No newline at end of file
